==> magic3_1.6.3_src.tar.gz: magic3/widgets/default_mainmenu/include/help/index.php <==
<?php
/**
 * ヘルプリソースファイル
 * index.php
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: index.php 1024 2008-09-19 09:12:21Z fishbone $
 * @link       http://www.magic3.org
 */
// 直接アクセスの防止
defined('M3_SYSTEM') or die('Access error: Direct access denied.');

global $HELP;

// ########## メインメニュー項目一覧 ##########
$HELP['mainmenu_list']['title'] = 'メインメニュー項目一覧';
$HELP['mainmenu_list']['body'] = 'メインメニューのメニュー項目一覧です。';
$HELP['mainmenu_detail']['title'] = 'メインメニュー項目詳細';
$HELP['mainmenu_detail']['body'] = 'メインメニュー項目の設定を編集します。';
$HELP['mainmenu_check']['title'] = '選択用チェックボックス';
$HELP['mainmenu_check']['body'] = '編集や削除を行う項目を選択します。';
$HELP['mainmenu_name']['title'] = '名前';
$HELP['mainmenu_name']['body'] = 'メニュー項目の名前です。';
$HELP['mainmenu_link_url']['title'] = 'リンク先URL';
$HELP['mainmenu_link_url']['body'] = 'メニュー項目をクリックしたときに表示されるURLです。';
$HELP['mainmenu_link_type']['title'] = '表示方法';
$HELP['mainmenu_link_type']['body'] = 'メニュー項目をクリックしたときにリンク先が同じウィンドウで表示するか、別ウィンドウで表示するかを指定します。';
$HELP['mainmenu_visible']['title'] = '公開';
$HELP['mainmenu_visible']['body'] = 'メニュー項目をユーザに公開するかどうかを制御します。非公開に設定の場合はユーザから参照することはできません。';
$HELP['mainmenu_act']['title'] = '操作';
$HELP['mainmenu_act']['body'] = '各種操作を行います。<br />●コンテンツを編集<br />メニュー項目のリンク先がコンテンツ表示の場合、表示されるコンテンツの編集を行います。';
$HELP['mainmenu_sel_link']['title'] = 'リンク先を選択';
$HELP['mainmenu_sel_link']['body'] = 'リンク先を選択します。「コンテンツ」を選択した場合は、表示するコンテンツを指定します。[任意設定]を選択した場合は、任意のURLにリンク先を設定できます。';
$HELP['mainmenu_new_btn']['title'] = '新規ボタン';
$HELP['mainmenu_new_btn']['body'] = '新規メニュー項目を追加します。';
$HELP['mainmenu_edit_btn']['title'] = '編集ボタン';
$HELP['mainmenu_edit_btn']['body'] = '選択されているメニュー項目を編集します。<br />メニュー項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['mainmenu_del_btn']['title'] = '削除ボタン';
$HELP['mainmenu_del_btn']['body'] = '選択されているメニュー項目を削除します。<br />メニュー項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['mainmenu_ret_btn']['title'] = '戻るボタン';
$HELP['mainmenu_ret_btn']['body'] = 'メニュー項目一覧へ戻ります。';
?>

==> magic3_1.17.14_src.tar.gz: magic3/widgets/default_mainmenu/include/help/index.php <==
<?php
/**
 * ヘルプリソースファイル
 * index.php
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: index.php 1252 2008-11-18 11:26:07Z fishbone $
 * @link       http://www.magic3.org
 */
// 直接アクセスの防止
defined('M3_SYSTEM') or die('Access error: Direct access denied.');

global $HELP;

// ########## メインメニュー項目一覧 ##########
$HELP['mainmenu_list']['title'] = 'メインメニュー項目一覧';
$HELP['mainmenu_list']['body'] = 'メインメニューのメニュー項目一覧です。「通常時メニュー」はログインしていない場合に表示されるメインメニューで、「ログイン時メニュー」はログインしている場合に表示されるメインメニューです。「ログイン時メニュー」に項目が登録されていない場合は、ログイン時も「通常時メニュー」が表示されます。';
$HELP['mainmenu_detail']['title'] = 'メインメニュー項目詳細';
$HELP['mainmenu_detail']['body'] = 'メインメニュー項目の設定を編集します。';
$HELP['mainmenu_check']['title'] = '選択用チェックボックス';
$HELP['mainmenu_check']['body'] = '編集や削除を行う項目を選択します。';
$HELP['mainmenu_name']['title'] = '名前';
$HELP['mainmenu_name']['body'] = 'メニュー項目の名前です。';
$HELP['mainmenu_link_url']['title'] = 'リンク先URL';
$HELP['mainmenu_link_url']['body'] = 'メニュー項目をクリックしたときに表示されるURLです。';
$HELP['mainmenu_link_type']['title'] = '表示方法';
$HELP['mainmenu_link_type']['body'] = 'メニュー項目をクリックしたときにリンク先が同じウィンドウで表示するか、別ウィンドウで表示するかを指定します。';
$HELP['mainmenu_visible']['title'] = '公開';
$HELP['mainmenu_visible']['body'] = 'メニュー項目をユーザに公開するかどうかを制御します。非公開に設定の場合はユーザから参照することはできません。';
$HELP['mainmenu_act']['title'] = '操作';
$HELP['mainmenu_act']['body'] = '各種操作を行います。<br />●コンテンツを編集<br />メニュー項目のリンク先がコンテンツ表示の場合、表示されるコンテンツの編集を行います。';
$HELP['mainmenu_sel_link']['title'] = 'リンク先を選択';
$HELP['mainmenu_sel_link']['body'] = 'リンク先を選択します。「コンテンツ」を選択した場合は、表示するコンテンツを指定します。[任意設定]を選択した場合は、任意のURLにリンク先を設定できます。';
$HELP['mainmenu_new_btn']['title'] = '新規ボタン';
$HELP['mainmenu_new_btn']['body'] = '新規メニュー項目を追加します。';
$HELP['mainmenu_edit_btn']['title'] = '編集ボタン';
$HELP['mainmenu_edit_btn']['body'] = '選択されているメニュー項目を編集します。<br />メニュー項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['mainmenu_del_btn']['title'] = '削除ボタン';
$HELP['mainmenu_del_btn']['body'] = '選択されているメニュー項目を削除します。<br />メニュー項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['mainmenu_ret_btn']['title'] = '戻るボタン';
$HELP['mainmenu_ret_btn']['body'] = 'メニュー項目一覧へ戻ります。';
?>
